==> profile-changer-widget_0.9-2.tar.gz: profile-changer-widget-0.9/src/profilechangerwidget_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>ProfileChangerWidget</name>
    <message>
        <location filename="profilechangerwidget.ui" line="14"/>
        <source>ProfileChangerWidget</source>
        <translation>Profilwechsel Widget</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="14"/>
        <source>Profile Channger Widget settings</source>
        <translation>Einstellungen für das Profilwechsel Widget</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="35"/>
        <source>Height (px)</source>
        <translation>Höhe (px)</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="55"/>
        <source>Width (px)</source>
        <translation>Breite (px)</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="75"/>
        <source>Icon</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="82"/>
        <source>Next Profile</source>
        <translation>Nächstes Profil</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="92"/>
        <source>Opacity (%)</source>
        <translation>Undurchsichtigkeit (%)</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="115"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="122"/>
        <source>Feedback</source>
        <translation>Feedback</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="129"/>
        <source>Donate</source>
        <translation>Schenken</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="28"/>
        <source>Fields cannot be empty!</source>
        <translation>Die Felder dürfen nicht leer sein!</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="44"/>
        <source>About Profile Changer Widget</source>
        <translation>Über Profilwechsel Widget</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="47"/>
        <source>Profile Changer Widget</source>
        <translation>Profilwechsel Widget</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="49"/>
        <source>Small widget intended to enable an easy change between general and silent profiles.</source>
        <translation>Kleines Widget zum Wechseln des Profils zwischen Allgemein und Stumm.</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="51"/>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
</context>
</TS>

==> profile-changer-widget_0.9.4-1.tar.gz: profile-changer-widget-0.9.4/src/profilechangerwidget_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>ProfileChangerWidget</name>
    <message>
        <location filename="profilechangerwidget.ui" line="14"/>
        <source>ProfileChangerWidget</source>
        <translation>Profilwechsel Widget</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="14"/>
        <source>Profile Channger Widget settings</source>
        <translation>Einstellungen für das Profilwechsel Widget</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="35"/>
        <source>Height (px)</source>
        <translation>Höhe (px)</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="55"/>
        <source>Width (px)</source>
        <translation>Breite (px)</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="75"/>
        <source>Icon</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="82"/>
        <source>Next Profile</source>
        <translation>Nächstes Profil</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="92"/>
        <source>Opacity (%)</source>
        <translation>Undurchsichtigkeit (%)</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="115"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="122"/>
        <source>Feedback</source>
        <translation>Feedback</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="129"/>
        <source>Donate</source>
        <translation>Schenken</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="28"/>
        <source>Fields cannot be empty!</source>
        <translation>Die Felder dürfen nicht leer sein!</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="44"/>
        <source>About Profile Changer Widget</source>
        <translation>Über Profilwechsel Widget</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="47"/>
        <source>Profile Changer Widget</source>
        <translation>Profilwechsel Widget</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="49"/>
        <source>Small widget intended to enable an easy change between general and silent profiles.</source>
        <translation>Kleines Widget zum Wechseln des Profils zwischen Allgemein und Stumm.</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="51"/>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="77"/>
        <source>Thank you for installing profile changer widget.</source>
        <translation>Vielen Dank, dass Sie das Profilwechsel Widget installiert haben.</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="80"/>
        <source>Thank you for updating profile changer widget.</source>
        <translation>Vielen Dank, dass Sie das Profilwechsel Widget aktualisiert haben.</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="83"/>
        <source>Feel free to support my work by testing the application in order to get it to Extras -repository.</source>
        <translation>Sie können meine Arbeit durch das Testen der Software unterstützen, um die Anwendung in das Extras-Repository zu bekommen.</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="85"/>
        <source>Therefore you can use the &quot;Feedback&quot; button.</source>
        <translation>Auf die Website gelangen Sie durch Drücken des &quot;Feedback&quot; Knopfs.</translation>
    </message>
</context>
</TS>
